Guide
=====

This is a Python package for the quantitative analysis of the interaction of energetic x-rays with matter.
This package is named after one of the discoverers of X-rays, `Wilhelm Roentgen <https://en.wikipedia.org/wiki/Wilhelm_Röntgen>`_.
He was awarded the very first Nobel Prize in Physics "in recognition of the extraordinary services he has rendered by the discovery of the remarkable rays subsequently named after him".
X-rays were originally referred to as Roentgen rays.

The scope of this package is evolving but it currently includes the penetration or absorption of x-rays in materials.
These materials may be metals, gases, biological, or detector materials.
It also includes the generation of x-rays from emission lines as well as emission lines from radionuclides.

.. toctree::
    :maxdepth: 3

    transmission_bkg
    transmission
    element_list
    attenuators
    cxro_compare
    lines
    emission_line_list
    nuclides
    nuclides_list
    gui